You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@tomcat.apache.org by ma...@apache.org on 2015/11/02 16:15:20 UTC

svn commit: r1712039 - /tomcat/tc6.0.x/trunk/java/org/apache/tomcat/jni/Library.java

Author: markt
Date: Mon Nov  2 15:15:20 2015
New Revision: 1712039

URL: http://svn.apache.org/viewvc?rev=1712039&view=rev
Log:
Correct back-port so it compiles with Java 5

Modified:
    tomcat/tc6.0.x/trunk/java/org/apache/tomcat/jni/Library.java

Modified: tomcat/tc6.0.x/trunk/java/org/apache/tomcat/jni/Library.java
URL: http://svn.apache.org/viewvc/tomcat/tc6.0.x/trunk/java/org/apache/tomcat/jni/Library.java?rev=1712039&r1=1712038&r2=1712039&view=diff
==============================================================================
--- tomcat/tc6.0.x/trunk/java/org/apache/tomcat/jni/Library.java (original)
+++ tomcat/tc6.0.x/trunk/java/org/apache/tomcat/jni/Library.java Mon Nov  2 15:15:20 2015
@@ -32,7 +32,7 @@ public final class Library {
      */
     private static Library _instance = null;
 
-    private Library() throws Exception {
+    private Library() throws Throwable {
         boolean loaded = false;
         String path = System.getProperty("java.library.path");
         String [] paths = path.split(File.pathSeparator);
@@ -170,9 +170,9 @@ public final class Library {
      * @return {@code true} if the native code was initialized successfully
      *         otherwise {@code false}
      *
      * @throws Exception if a problem occurred during initialization
      */
-    public synchronized static boolean initialize(String libraryName) throws Exception {
+    public static synchronized boolean initialize(String libraryName) throws Throwable {
         if (_instance == null) {
             if (libraryName == null)
                 _instance = new Library();



---------------------------------------------------------------------
@@ -170,9 +170,9 @@ public final class Library {
      *         otherwise {@code false}
      *
-     * @throws Exception if a problem occurred during initialization
+     * @throws Throwable if a problem occurred during initialization
      */
To unsubscribe, e-mail: dev-unsubscribe@tomcat.apache.org
For additional commands, e-mail: dev-help@tomcat.apache.org